@@ -28,6 +28,7 @@
 #include "poi.h"
 #include "wp.h"
 #include "tracks.h"
+#include "hrm_functions.h"
 
 #define WTFCOUNTER 5
 
@@ -238,7 +239,7 @@ on_drawingarea1_button_release_event   (GtkWidget       *widget,
 				gtk_widget_show(menu1);
 				
 				gtk_menu_popup (GTK_MENU(menu1), NULL, NULL, NULL, NULL, 
-					  event->button, event->time);
+					  0, event->time);
 				
 			}
 			
@@ -290,6 +291,8 @@ on_drawingarea1_motion_notify_event    (GtkWidget       *widget,
 	 
 		if (state & GDK_BUTTON1_MASK  && wtfcounter>=WTFCOUNTER) 
 		{
+			GtkToggleToolButton *autocenter_toggle;
+
 			if(!drag_started)
 			{
 				mouse_x = (int) event->x;
@@ -330,6 +333,17 @@ on_drawingarea1_motion_notify_event    (GtkWidget       *widget,
 					widget->allocation.width,
 					mouse_dy);
 					
+			autocenter_toggle =
+				GTK_TOGGLE_TOOL_BUTTON(lookup_widget(window1,
+				                                     "button3"));
+			gtk_toggle_tool_button_set_active(autocenter_toggle,
+			                                  FALSE);
+
+			autocenter_toggle =
+				GTK_TOGGLE_TOOL_BUTTON(lookup_widget(window1,
+				                                     "button56"));
+			gtk_toggle_tool_button_set_active(autocenter_toggle,
+			                                  FALSE);
 
 		}	
 		else
@@ -401,27 +415,26 @@ on_drawingarea1_expose_event           (GtkWidget       *widget,
 		event->area.width, event->area.height);
 	
 	osd_speed(TRUE);
+	osd_hrm(TRUE);
 	map_scale_indicator();
 	
 	return FALSE;
 }
 
 void
-on_button1_clicked                     (GtkButton       *button,
+on_button1_clicked                     (GtkToggleToolButton *button,
                                         gpointer         user_data)
-{	
-	if(!maximized)
-	{		
+{
+	maximized = gtk_toggle_tool_button_get_active (button);
+
+	if(maximized)
+	{
 		gtk_window_fullscreen(GTK_WINDOW(window1));
 		fill_tiles_pixel(global_x, global_y, global_zoom, FALSE);
-
-		maximized = TRUE;
 	}
 	else
 	{
 		gtk_window_unfullscreen(GTK_WINDOW(window1));
-
-		maximized = FALSE;
 	}
 }
 
@@ -469,11 +482,14 @@ on_button4_clicked                     (GtkButton       *button,
 
 
 void
-on_button3_clicked                     (GtkButton       *button,
+on_button3_clicked                     (GtkToggleToolButton *button,
                                         gpointer         user_data)
 {
-	global_autocenter = TRUE;
-	
+	global_autocenter = gtk_toggle_tool_button_get_active(button);
+
+	if (!global_autocenter)
+		return;
+
 	if(gpsdata) {
 		if(isnan(gpsdata->fix.latitude) == 0	&&
 		   isnan(gpsdata->fix.longitude)== 0	&&
@@ -492,6 +508,8 @@ on_window1_delete_event                (GtkWidget       *widget,
                                         gpointer         user_data)
 {
 	printf("%s()\n",__PRETTY_FUNCTION__);
+
+	track_log_close ();
 	gtk_main_quit();
 	
 	return FALSE; 
@@ -504,7 +522,10 @@ on_window1_destroy_event               (GtkWidget       *widget,
                                         gpointer         user_data)
 {
 	printf("%s()\n",__PRETTY_FUNCTION__);
+
+	track_log_close ();
 	gtk_main_quit();
+
 	return FALSE;
 }
 
@@ -816,7 +837,7 @@ on_button11_clicked                    (GtkButton       *button,
 		widget = lookup_widget(window1, "image24");
 		gtk_widget_show(widget);
 		
-		gtk_button_set_label(button, "Stop");
+		gtk_button_set_label (button, _("Stop"));
 		
 		widget = lookup_widget(menu1, "item19");
 		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widget), TRUE);
@@ -837,7 +858,7 @@ on_button11_clicked                    (GtkButton       *button,
 		msg_timer =0;
 		global_fftimer_running = FALSE;
 		
-		gtk_button_set_label(button, "Share!");
+		gtk_button_set_label (button, _("Share!"));
 	}
 
 	
@@ -906,7 +927,7 @@ on_item3_activate                      (GtkMenuItem     *menuitem,
 	
 	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
-	g_sprintf(buffer, "<b><i>Distance:</i></b> %.3fkm\n",distance);
+	g_sprintf (buffer, _("<b><i>Distance:</i></b> %.3fkm\n"), distance);
 	
 	for(list = friends_list; list != NULL; list = list->next)
 	{
@@ -931,7 +952,7 @@ on_item3_activate                      (GtkMenuItem     *menuitem,
 	}
 	
 	if (!friend_found)
-		g_sprintf(buffer,"No friends at or near this position");
+		g_sprintf (buffer, _("No friends at or near this position"));
 
 
 	label = lookup_widget(window,"label119");
@@ -943,7 +964,7 @@ on_item4_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
 	GtkWidget *label;
-	gchar buffer[512];
+	gchar buffer[512]; gchar *bufp;
 	gchar latlon[64];
 	static float start_lat=0, start_lon=0;
 	static float overall_distance = 0;
@@ -1038,35 +1059,35 @@ on_item4_activate                      (GtkMenuItem     *menuitem,
 	
 	
 	label = lookup_widget(window2,"label64");
-	
-	if(!distance_mode && gpsdata && gpsdata->fix.latitude)
+
+	bufp = buffer;
+	bufp += g_sprintf (bufp, _("<b>This point:</b>\n%s\n"
+	                           "<small><i>(coords auto-copied to clipboard)\n</i></small>\n"),
+	                   latlon);
+
+	if (gpsdata && gpsdata->fix.latitude)
 	{
-		g_sprintf(buffer,"<b>This point:</b> \n%s \n"
-				"<small><i>(coords auto-copied to clipboard)\n</i></small>\n"
-				"<b>Bearing:</b>\n%.1f°\n"
-				"<b>Distance from your location:</b>\n%.2f%s\n"
-				"Click another point for distance",
-				latlon, bearing/M_PI*180, 
-				distance*unit_conv, distunit);
+		bufp += g_sprintf (bufp, _("<b>Bearing:</b>\n%.1f°\n"),
+		                   bearing/M_PI*180);
+
+		if (!distance_mode)
+		{
+			bufp += g_sprintf (bufp, _("<b>Distance from your location:</b>\n%.2f%s\n"),
+			                   distance*unit_conv,
+			                   distunit);
+		}
 	}
-	else if (!distance_mode && (!gpsdata || (gpsdata && !gpsdata->fix.latitude)))
+
+	if (!distance_mode)
 	{
-		g_sprintf(buffer,"<b>This point:</b> \n%s \n"
-				"<small><i>(coords auto-copied to clipboard)\n</i></small>\n" 
-				"Click another point for distance",
-				latlon);		
+		bufp += g_sprintf (bufp, _("Click another point for distance"));
 	}
 	else
 	{
-		g_sprintf(buffer,"<b>This point:</b> \n%s \n"
-				"<small><i>(coords auto-copied to clipboard)\n</i></small>\n"
-				"<b>Bearing:</b>\n%.1f°\n"
-				"<b>Distance from last point:</b>\n%.2f%s\n"
-				"<b>Overall Distance:</b>\n%.2f%s",
-				latlon, bearing/M_PI*180, 
-				distance*unit_conv, distunit, 
-				overall_distance*unit_conv, distunit);
-		
+		bufp += g_sprintf (bufp, _("<b>Distance from last point:</b>\n%.2f%s\n"),
+		                   distance*unit_conv, distunit);
+		bufp += g_sprintf (bufp, _("<b>Overall Distance:</b>\n%.2f%s"),
+		                   overall_distance*unit_conv, distunit);
 	}
 	
 	gtk_label_set_label(GTK_LABEL(label),buffer);
@@ -1200,14 +1221,14 @@ on_item5_activate                      (GtkWidget       *widget,
 	global_myposition.lon = lon_deg;
 
 	label = lookup_widget(window2,"label64");
-	
-	g_sprintf(buffer,"<b>Manually set position</b>\n\nThis point: \n\n"
-			"  <i>%f %f</i> \n\n"
-			"will now be used as your location\n"
-			"for the friend finder service.",
-			global_myposition.lat,
-			global_myposition.lon);
-			
+
+	g_sprintf (buffer, _("<b>Manually set position</b>\n\n"
+	                     "This point:\n\n  <i>%f %f</i>\n\n"
+	                     "will now be used as your location\n"
+	                     "for the friend finder service."),
+	           global_myposition.lat,
+	           global_myposition.lon);
+
 	gtk_label_set_label(GTK_LABEL(label),buffer);
 	gtk_widget_show (window2);
 	
@@ -1316,9 +1337,9 @@ on_button15_clicked                    (GtkButton       *button,
 	trip_counter_on = (trip_counter_on) ? FALSE : TRUE;
 	
 	if(trip_counter_on)
-		gtk_button_set_label(button, "Stop");
+		gtk_button_set_label (button, _("Stop"));
 	else
-		gtk_button_set_label(button, "Resume");
+		gtk_button_set_label (button, _("Resume"));
 }
 
 void
@@ -1646,7 +1667,7 @@ on_item10_activate                     (GtkMenuItem     *menuitem,
 			if(!photo)
 			{
 				printf ("+++++++++++++ FOTO NOT FOUND +++++++++\n");
-				g_sprintf(buffer, "File not found");
+				g_sprintf (buffer, _("File not found"));
 			}
 			else
 			{
@@ -1695,7 +1716,7 @@ on_item10_activate                     (GtkMenuItem     *menuitem,
 	}
 	
 	if(!photo_found)
-		g_sprintf(buffer, "No Geo Photo found");
+		g_sprintf (buffer, _("No Geo Photo found"));
 	
 	gtk_label_set_text(GTK_LABEL(label),buffer);
 
@@ -1755,7 +1776,7 @@ printf("*** %s(): \n",__PRETTY_FUNCTION__);
 	if(!photo)
 	{
 		printf ("+++++++++++++ FOTO NOT FOUND: %s +++++++++\n", photo_file);
-		g_sprintf(buffer, "File not found");
+		g_sprintf (buffer, _("File not found"));
 	}
 	else
 	{
@@ -2320,7 +2341,10 @@ on_button33_clicked                    (GtkButton       *button,
 	widget = lookup_widget(window, "label126");
 	
 	if (p->idmd5==NULL)
-		gtk_label_set_label(GTK_LABEL(widget), "<span foreground='#ff0000'>POI has no ID -> see website for help!</span>");
+		gtk_label_set_label (GTK_LABEL(widget),
+		                     _("<span foreground='#ff0000'>"
+		                       "POI has no ID -> see website for help!"
+		                       "</span>"));
 	else
 		gtk_label_set_text(GTK_LABEL(widget), p->idmd5);
 
@@ -2395,7 +2419,11 @@ on_drawingarea1_key_press_event        (GtkWidget       *widget,
 	else if(event->keyval == 'm')
 		on_button76_clicked(NULL, NULL);
 	else if(event->keyval == GDK_space || event->keyval == GDK_F11)
-		on_button1_clicked(GTK_BUTTON(lookup_widget(window1, "button1")), NULL);
+	{
+		maximized = !maximized;
+		gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(lookup_widget(window1, "button1")), maximized);
+		gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(lookup_widget(window1, "button53")), maximized);
+	}
 	else if(event->keyval == GDK_Right)
 		move_map(1);
 	else if(event->keyval == GDK_Down)
@@ -2405,7 +2433,22 @@ on_drawingarea1_key_press_event        (GtkWidget       *widget,
 	else if(event->keyval == GDK_Up)
 		move_map(4);
 	else if(event->keyval == GDK_a)
-		on_button3_clicked(GTK_BUTTON(lookup_widget(window1,"button3")), NULL);
+	{
+		global_autocenter = !global_autocenter;
+		GtkToggleToolButton *autocenter_toggle;
+
+		autocenter_toggle =
+			GTK_TOGGLE_TOOL_BUTTON(lookup_widget(window1,
+			                                     "button3"));
+		gtk_toggle_tool_button_set_active(autocenter_toggle,
+		                                  global_autocenter);
+
+		autocenter_toggle =
+			GTK_TOGGLE_TOOL_BUTTON(lookup_widget(window1,
+			                                     "button56"));
+		gtk_toggle_tool_button_set_active(autocenter_toggle,
+		                                  global_autocenter);
+	}
 	else if(event->keyval == GDK_r)
 		on_item23_button_release_event(NULL, NULL, NULL);
 	else if(event->keyval == GDK_1)
@@ -2548,13 +2591,13 @@ on_button35_clicked                    (GtkButton       *button,
 	{	
 		gtk_widget_hide(widget);
 		msg_pane_visible = FALSE;
-		gtk_button_set_label(button, "Show Messages");
+		gtk_button_set_label (button, _("Show Messages"));
 	}
 	else
 	{
 		gtk_widget_show(widget);
 		msg_pane_visible = TRUE;
-		gtk_button_set_label(button, "Hide Messages");
+		gtk_button_set_label (button, _("Hide Messages"));
 	}
 }
 
@@ -3343,7 +3386,7 @@ on_eventbox5_button_release_event      (GtkWidget       *widget,
 		if(!global_infopane_visible)
 		{
 			widget = lookup_widget(window1, "button76");
-			gtk_button_clicked(GTK_BUTTON(widget));
+			g_signal_emit_by_name (widget, "clicked");
 		}
 		
 		gtk_widget_hide(global_infopane_current->data);
@@ -3460,7 +3503,8 @@ on_okbutton11_clicked                  (GtkButton       *button,
 	
 	widget = lookup_widget(GTK_WIDGET(button), "label190");
 	
-	gtk_label_set_label(GTK_LABEL(widget),"<b><i>Connecting...</i></b>");
+	gtk_label_set_label (GTK_LABEL(widget),
+	                     _("<b><i>Connecting...</i></b>"));
 	
 	widget = lookup_widget(GTK_WIDGET(button), "entry31");
 	start = g_strdup( gtk_entry_get_text(GTK_ENTRY(widget)) );
@@ -3641,6 +3685,7 @@ void
 move_map(int i)
 {
 	GtkWidget *widget = NULL;
+	GtkToggleToolButton *autocenter_toggle;
 
 	widget = lookup_widget(window1, "drawingarea1");
 	
@@ -3665,9 +3710,15 @@ move_map(int i)
 	gtk_widget_queue_draw_area (
 		widget, 
 		0,0,widget->allocation.width+260,widget->allocation.height+260);
-	
-	global_autocenter = FALSE;
-	
+
+	autocenter_toggle =
+		GTK_TOGGLE_TOOL_BUTTON(lookup_widget(window1, "button3"));
+	gtk_toggle_tool_button_set_active(autocenter_toggle, FALSE);
+
+	autocenter_toggle =
+		GTK_TOGGLE_TOOL_BUTTON(lookup_widget(window1, "button56"));
+	gtk_toggle_tool_button_set_active(autocenter_toggle, FALSE);
+
 	repaint_all();
 }
 
@@ -3740,6 +3791,47 @@ on_entry29_changed                     (GtkEditable     *editable,
 	gconf_client_set_string(global_gconfclient, GCONF"/me_msg", me_msg, NULL);
 }
 
+void
+on_checkbutton18_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	GtkWidget *widget;
+	
+	hrm_on = gtk_toggle_button_get_active(togglebutton);
+	
+	gconf_client_set_bool(	global_gconfclient, 
+				GCONF"/hrm_on",
+				hrm_on, NULL);
+
+	global_reconnect_hrm = TRUE;
+	
+	widget = lookup_widget(window1, "label205");
+	(hrm_on) ? gtk_widget_show(widget) : gtk_widget_hide(widget);
+
+	widget = lookup_widget(window1, "label206");
+	(hrm_on) ? gtk_widget_show(widget) : gtk_widget_hide(widget);
+
+	widget = lookup_widget(window1, "label207");
+	(hrm_on) ? gtk_widget_show(widget) : gtk_widget_hide(widget);
+}
+
+
+void
+on_entry33_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data)
+{
+	const char *entry;
+	
+	entry = gtk_entry_get_text(GTK_ENTRY(editable));
+	
+	gconf_client_set_string(global_gconfclient, 
+				GCONF"/hrm_bt_addr",
+				entry, NULL);
+	
+	global_hrm_bt_addr = g_strdup(entry);
+	global_reconnect_hrm = TRUE;
+}
+
 void
 set_map_detail_menuitem_sensitivity (GtkMenuItem *zoomout, GtkMenuItem *menu)
 {
@@ -3787,3 +3879,14 @@ activate_larger_map_details (GtkMenuItem *larger_item, GtkMenuItem *more_item)
 
 	repaint_all ();
 }
+
+
+void
+toggle_tile_redownload (GtkToggleButton *togglebutton, gpointer data)
+{
+	global_no_redownload = !gtk_toggle_button_get_active (togglebutton);
+
+	gconf_client_set_bool (global_gconfclient, 
+	                       GCONF"/no_redownload",
+	                       global_no_redownload, NULL);
+}
